#' faux: Simulation Functions.
#'
#' The faux package provides functions for simulating datasets with specified structure.
#'
#' @name faux
#' @keywords internal
#' @import ggplot2
#' @importFrom stats cor sd
"_PACKAGE"

